package Inline::CPP::Config;

# Configuration data for CPP.pm; Compiler, libs, iostream filename, #defines.

use strict;
use warnings;

our $VERSION = '0.80';
#$VERSION = eval $VERSION; ## no critic (eval)

our $compiler = 'g++ -D_REENTRANT -D_GNU_SOURCE -fwrapv -fno-strict-aliasing -pipe -fstack-protector-strong -I/usr/include/db5.3 -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64 -xc++';
our $libs     = '-lstdc++';

our $iostream_fn = 'iostream';

our $cpp_flavor_defs =  <<'END_FLAVOR_DEFINITIONS';

#define __INLINE_CPP_STANDARD_HEADERS 1
#define __INLINE_CPP_NAMESPACE_STD 1


END_FLAVOR_DEFINITIONS

1;

__END__

=head1 NAME

Inline::CPP::Config - for internal consumption; nothing to document
